<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>Show YouTube movies in chat window</source>
        <translation>Afficher les vidéos YouTube dans le canal de discussion</translation>
    </message>
    <message>
        <source>Show images in chat window</source>
        <translation>Afficher les images dans le canal de discussion</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Messages</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>